@@ -1263,8 +1263,10 @@ impl Formatter {
                         let (am_pm, rem) = parse_ampm(s, style)?;
                         s = rem;
 
-                        dt.ampm = Some(am_pm);
-                        dt.adjust_hour12();
+                        dt.ampm = am_pm;
+                        if dt.ampm.is_some() {
+                            dt.adjust_hour12();
+                        }
                     } else {
                         return Err(Error::ParseError("date format not recognized".to_string()));
                     }
@@ -1400,25 +1402,25 @@ fn parse_year(input: &[u8], max_len: usize, current_year: i32) -> Result<(bool,
 }
 
 #[inline]
-fn parse_ampm<'a>(s: &'a [u8], style: &'a AmPmStyle) -> Result<(AmPm, &'a [u8])> {
+fn parse_ampm<'a>(s: &'a [u8], style: &'a AmPmStyle) -> Result<(Option<AmPm>, &'a [u8])> {
     if s.is_empty() {
-        return Ok((AmPm::Am, s));
+        return Ok((None, s));
     }
     match style {
         AmPmStyle::LowerDot | AmPmStyle::UpperDot => {
             if CaseInsensitive::starts_with(s, b"A.M.") {
-                Ok((AmPm::Am, &s[4..]))
+                Ok((Some(AmPm::Am), &s[4..]))
             } else if CaseInsensitive::starts_with(s, b"P.M.") {
-                Ok((AmPm::Pm, &s[4..]))
+                Ok((Some(AmPm::Pm), &s[4..]))
             } else {
                 Err(Error::ParseError("AM/A.M. or PM/P.M. required".to_string()))
             }
         }
         AmPmStyle::Upper | AmPmStyle::Lower => {
             if CaseInsensitive::starts_with(s, b"AM") {
-                Ok((AmPm::Am, &s[2..]))
+                Ok((Some(AmPm::Am), &s[2..]))
             } else if CaseInsensitive::starts_with(s, b"PM") {
-                Ok((AmPm::Pm, &s[2..]))
+                Ok((Some(AmPm::Pm), &s[2..]))
             } else {
                 Err(Error::ParseError("AM/A.M. or PM/P.M. required".to_string()))
             }
